// |$Id: genbazi.c,v 1.1.1.1 2022/12/27 22:03:00 pm Exp $           |
/* |------------------------------------------------------------|
   | Basic Seismic Utilities (BSU)                              | 
   | LANGUAGE: C                                                |
   | AUTHOR: P.MICHAELS <paulmichaels@boisestate.boisestate.edu>|
   | FUNCTION NAME: genplot                                     |
   | Copyright (C) 2021 P. Michaels  (See GNU License)          |
   |------------------------------------------------------------|
   |                                                            |
   | purpose:  Generate A Sequence of bazi runs                 |
   |------------------------------------------------------------|
*/
      #include <stdio.h>
      #include <stdlib.h>
      #include <float.h>
      #include <math.h>
      #include <string.h>
      #include <time.h>

int 	main(int argc, char *argv[]) {
	FILE	*h1, *h2;
	char	outfile[]="gobazi";
	char	gpfile[]="PCA.gp";
	char	infile[20];
	char	infileshort[13];
	char	tail[]=".seg";
	float	tend;
	float	tstart;
	float	tstep;
	float	tgate;
	float	tlagmx;
	int	j, nstep;
	float	t1, t2;
	int	chR;
	int	chT;
	int	ipct;
	float	tsw1;
	#ifdef WIN
	char Xwin[4]="wxt";
	#else
	char Xwin[4]="x11";
	#endif
	if(argc<10 ) {
	puts("USAGE: genbazi filename tstart tend tstep tgate chR chT ipct tsw1  \n");
	puts("filename = input file name");
	puts("tstart   = start time (float, seconds) of processing");
	puts("tend     = end time (float, seconds) of processing)");
	puts("tstep    = time shift forward with sliding window (float, seconds) of processing)");
	puts("tgate    = length in time of sliding window (float, seconds)  ");
	puts("chR      = channel with R-component (int)                                        ");
	puts("chT      = channel with T-component (int)                                        ");
	puts("ipct     = percent of max amplitude to include in window (int)                   ");
	puts("tsw1     = switch to set T-component relative to R-component                     ");
	puts("           Example:  tsw1=+90. IF R=90 (East) and T=180 (South)                  ");
	puts("                     tsw1=-90. IF R=90 (EAST) and T=0 (North)                    ");
	puts("\n ABORT");
	fprintf(stderr," you only have %d arguments on command line \n",argc);
	for (j=0; j<argc; j++) fprintf(stderr,"argv[%d] = %s \n",j,argv[j]);
	return(1);
	}
	else {
	strncpy(infile,argv[1],19);
	tstart = atof(argv[2]);
	tend = atof(argv[3]);
	tstep = atof(argv[4]);
	tgate = atof(argv[5]);
	chR   = atoi(argv[6]);
	chT   = atoi(argv[7]);
	ipct  = atoi(argv[8]);
	tsw1  = atof(argv[9]);
	} //endif

//...Clean Files
//	int ret = system("rm -f bazipca.dat");
//	puts("cleaning pca list");
//	fprintf(stdout,"ret= %d \n",ret);


//open output file for writing
        if( (h1=fopen(outfile,"w"))==NULL )
        {
        printf("\n ABORT !! Error opening file %s \n",outfile);
	fflush(stderr);
	  abort();
        }
	fprintf(h1,"#!/bin/bash \n");

//...echocheck
	fprintf(h1,"# GENERATED BY GENBAZI.C          \n");
	fprintf(h1,"# ================================\n");
	fprintf(h1,"# Input File          = %s \n",infile);
	fprintf(h1,"# Start Time          = %.2f sec. \n",tstart);
	fprintf(h1,"# End Time            = %.2f sec. \n",tend);
	fprintf(h1,"# Time Step (moveups) = %.2f sec. \n",tstep);
	fprintf(h1,"# Time Gate           = %.2f sec. \n",tgate);
	fprintf(h1,"# chR                 = %d        \n",chR);
	fprintf(h1,"# chT                 = %d        \n",chT);
	fprintf(h1,"# ipct                = %d        \n",ipct);
	fprintf(h1,"# tsw1                = %f        \n",tsw1);
	fprintf(h1,"#  \n");

//...clean pre-existing PCA output
	fprintf(h1,"rm -f bazipca.dat \n");
	fprintf(h1,"rm -f bazihodo.ps \n");

// Generate loop of commands
	nstep = (tend - tstart)/tstep -1 ;
	t1=tstart;
	t2=t1 + tgate;
	fprintf(h1,"echo ""gate: %.1f %.1f "" \n ",t1,t2);
	fprintf(h1,"bazi %s %d %d %i %f %f %f >/dev/null \n",infile,chR,chT,ipct,tsw1,t1,t2);
	fprintf(h1,"cat bazi.ps >> bazihodo.ps \n");
	t1 = t1 + tstep;
	for (j=0; j<nstep-1; j++) {
	t2=t1 + tgate;
	fprintf(h1,"echo ""gate: %.1f %.1f "" \n ",t1,t2);
	fprintf(h1,"bazi %s %d %d %i %f %f %f >/dev/null \n",infile,chR,chT,ipct,tsw1,t1,t2);
	t1 = t1 + tstep; 	
	fprintf(h1,"cat bazi.ps >> bazihodo.ps \n");
	} //next j
	fprintf(h1,"ps2pdf bazihodo.ps \n");
	fprintf(h1,"gnuplot PCA.gp \n");

//open gnuplot file for writing
        if( (h2=fopen(gpfile,"w"))==NULL )
        {
        printf("\n ABORT !! Error opening file %s \n",gpfile);
	fflush(stderr);
	  abort();
        }

	fprintf(h2,"# GENERATED BY GENBAZI.C  \n");
	fprintf(h2,"# Channels: R=%d  T=%d \n",chR,chT);
	fprintf(h2,"set grid    \n");
	fprintf(h2,"set terminal %s persist \n",Xwin);
	fprintf(h2,"set key left    \n");
	fprintf(h2,"set xlabel 'Time (s)'    \n");
        fprintf(h2,"set ylabel 'Angle wrt R (deg) and Normalized Amp.' \n");
	fprintf(h2,"set title 'Horizontal Motion %s R=%d T=%d' \n",infile,chR,chT);
	fprintf(h2,"stats 'bazipca.dat' u 4    \n");
	fprintf(h2,"p 'bazipca.dat' u 1:3 w l lc 'red' lw 2 t 'angle wrt R',\\");
	fprintf(h2,"\n 'bazipca.dat' u 1:($4/STATS_max*200 ) \\");
	fprintf(h2,"\n w p pt 6 ps 1.5 lc 'blue'  t 'normalized amp'  \n");
	fprintf(h2,"set terminal postscript enhanced color   \n");
	fprintf(h2,"set output 'PCA.ps'    \n");
	fprintf(h2,"replot    \n");
   



//...cleanup
	fprintf(h1,"#rm -f bazi.ps \n");
	fprintf(h1,"#rm -f bazihodo.ps \n");

	fclose(h1);
	fclose(h2);
	system("chmod +x gobazi");
	puts("SUCESS Now you run the output script");
	printf("Output Bash Script ==> gobazi \n");
	printf("Script will run Gnuplot script after gobazi ==>PCA.gp ==>PCA.ps  \n"); 
} //endmain

